@@ -1,29 +1,18 @@
 /* idn2.h - header file for idn2
-   Copyright (C) 2011-2016 Simon Josefsson
+   Copyright (C) 2011 Simon Josefsson
 
-   Libidn2 is free software: you can redistribute it and/or modify it
-   under the terms of either:
-
-     * the GNU Lesser General Public License as published by the Free
-       Software Foundation; either version 3 of the License, or (at
-       your option) any later version.
-
-   or
-
-     * the GNU General Public License as published by the Free
-       Software Foundation; either version 2 of the License, or (at
-       your option) any later version.
-
-   or both in parallel, as here.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received copies of the GNU General Public License and
-   the GNU Lesser General Public License along with this program.  If
-   not, see <http://www.gnu.org/licenses/>.
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef _IDN2_H
@@ -56,7 +45,7 @@ extern "C"
  * version number.  Used together with idn2_check_version() to verify
  * header file and run-time library consistency.
  */
-#define IDN2_VERSION "0.14"
+#define IDN2_VERSION "0.3"
 
 /**
  * IDN2_VERSION_NUMBER
@@ -67,7 +56,7 @@ extern "C"
  * digits are used to enumerate development snapshots, but for all
  * public releases they will be 0000.
  */
-#define IDN2_VERSION_NUMBER 0x00140000
+#define IDN2_VERSION_NUMBER 0x00030000
 
 /**
  * IDN2_LABEL_MAX_LENGTH
@@ -92,8 +81,6 @@ extern "C"
  * idn2_flags:
  * @IDN2_NFC_INPUT: Normalize input string using normalization form C.
  * @IDN2_ALABEL_ROUNDTRIP: Perform optional IDNA2008 lookup roundtrip check.
- * @IDN2_TRANSITIONAL: Perform Unicode TR46 transitional processing.
- * @IDN2_NONTRANSITIONAL: Perform Unicode TR46 non-transitional processing.
  *
  * Flags to IDNA2008 functions, to be binary or:ed together.  Specify
  * only 0 if you want the default behaviour.
@@ -102,8 +89,6 @@ extern "C"
   {
     IDN2_NFC_INPUT = 1,
     IDN2_ALABEL_ROUNDTRIP = 2,
-    IDN2_TRANSITIONAL = 4,
-    IDN2_NONTRANSITIONAL = 8,
   } idn2_flags;
 
 /* IDNA2008 with UTF-8 encoded inputs. */
@@ -139,7 +124,6 @@ extern "C"
  * @IDN2_TOO_BIG_LABEL: Domain label longer than 63 characters.
  * @IDN2_INVALID_ALABEL: Input A-label is not valid.
  * @IDN2_UALABEL_MISMATCH: Input A-label and U-label does not match.
- * @IDN2_INVALID_FLAGS: Invalid combination of flags.
  * @IDN2_NOT_NFC: String is not NFC.
  * @IDN2_2HYPHEN: String has forbidden two hyphens.
  * @IDN2_HYPHEN_STARTEND: String has forbidden starting/ending hyphen.
@@ -151,9 +135,6 @@ extern "C"
  * @IDN2_CONTEXTO_NO_RULE: String has context-o character with no rull.
  * @IDN2_UNASSIGNED: String has forbidden unassigned character.
  * @IDN2_BIDI: String has forbidden bi-directional properties.
- * @IDN2_DOT_IN_LABEL: Label has forbidden dot (TR46).
- * @IDN2_INVALID_TRANSITIONAL: Label has character forbidden in transitional mode (TR46).
- * @IDN2_INVALID_NONTRANSITIONAL: Label has character forbidden in non-transitional mode (TR46).
  *
  * Return codes for IDN2 functions.  All return codes are negative
  * except for the successful code IDN2_OK which are guaranteed to be
@@ -177,7 +158,6 @@ extern "C"
     IDN2_TOO_BIG_LABEL = -206,
     IDN2_INVALID_ALABEL = -207,
     IDN2_UALABEL_MISMATCH = -208,
-    IDN2_INVALID_FLAGS = -209,
     IDN2_NOT_NFC = -300,
     IDN2_2HYPHEN = -301,
     IDN2_HYPHEN_STARTEND = -302,
@@ -188,10 +168,7 @@ extern "C"
     IDN2_CONTEXTO = -307,
     IDN2_CONTEXTO_NO_RULE = -308,
     IDN2_UNASSIGNED = -309,
-    IDN2_BIDI = -310,
-    IDN2_DOT_IN_LABEL = -311,
-    IDN2_INVALID_TRANSITIONAL = -312,
-    IDN2_INVALID_NONTRANSITIONAL = -313,
+    IDN2_BIDI = -310
   } idn2_rc;
 
 /* Auxilliary functions. */
