@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# Copyright (C) 2011-2016 Simon Josefsson
+# Copyright (C) 2011 Simon Josefsson
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,11 +21,9 @@
 use strict;
 
 my ($last);
-my ($lineno) = 0;
 my ($ctr) = 0;
 
 while (<>) {
-    $lineno++;
     next unless /^[BN]/;
 
     m,^.*;	(.*);	(.*);	(.*);	(NV8)?,;
@@ -57,7 +55,7 @@ while (<>) {
 
     next if ($ustr eq $last);
 
-    print "/* lineno $lineno ctr $ctr source $source uni $ustr ace $astr nv8 $nv8 line $line */\n";
+    print "/* $ctr source $source uni $ustr ace $astr nv8 $nv8 line $line */\n";
 
     if ($astr =~ /\\u/) {
 	print "/* IdnaTest.txt bug? */\n";
